===============================
Maastricht Diffusion Toolkit
===============================

.. image:: https://badge.fury.io/py/mdt.png
    :target: http://badge.fury.io/py/mdt

.. image:: https://travis-ci.org/robbert-harms/mdt.png?branch=master
        :target: https://travis-ci.org/robbert-harms/mdt

.. image:: https://pypip.in/d/mdt/badge.png
        :target: https://pypi.python.org/pypi/mdt


A diffusion toolkit for parallelized sampling and optimization of diffusion data.

* Free software: LGPL v3 license
* Documentation: https://mdt.readthedocs.org.

Features
========

Ubuntu / Debian installation:

python3
python3-numpy
python3-nibabel
python3-pyqt5
python3-pip
python3-matplotlib
python3-six
python3-numpy
python3-pyopencl
python3-yaml
python3-argcomplete
libpng-dev 
libfreetype6-dev 
libxft-dev

